require 'test/unit'
require 'rack/mock'
require 'notgun'

class NotgunLoaderTest < Test::Unit::TestCase
  def rackup_file(name)
    "#{File.dirname(__FILE__)}/#{name}"
  end

  def test_knows_the_rackup_file
    file = rackup_file('test.ru')
    notgun = Notgun::Loader.new(file)
    assert_equal file, notgun.rackup_file
  end

  def test_processes_requests
    file = rackup_file('test.ru')
    notgun = Notgun::Loader.new(file)
    request = Rack::MockRequest.new(notgun)
    res = request.get("/")
    assert_equal 200, res.status
    assert_equal "BANG!", res.body
    assert_equal "text/plain", res.headers['Content-Type']
  end

  def test_processes_large_requests
    file = rackup_file('big.ru')
    notgun = Notgun::Loader.new(file)
    request = Rack::MockRequest.new(notgun)
    res = request.get("/")
    assert_equal 200, res.status
    assert res.body =~ %r|<pre>(?:.{1023}\n){1024}</pre>|,
      "body of size #{res.body.size} does not match expected output"
  end

  def test_logging
    file = rackup_file('verbose.ru')

    $logger = File.open('test/verbose.log', 'w')
    $logger.sync = true

    notgun = Notgun::Loader.new(file)
    request = Rack::MockRequest.new(notgun)
    request.get('/', 'REMOTE_ADDR' => 'foo.local')

    $logger.close

    assert_match /^foo.local/, File.read('test/verbose.log')
  end
end
